@@ -9,14 +9,14 @@ var searchData=
   ['uint64_6',['uint64',['../group__juce__core-maths.html#gaba41bf2b6f6da5945ee08fb99931aede',1,'juce_MathsFunctions.h']]],
   ['uint8_7',['uint8',['../group__juce__core-maths.html#ga34ecedcf03a70dc91e4616212d79267d',1,'juce_MathsFunctions.h']]],
   ['uiviewcomponent_8',['UIViewComponent',['../classUIViewComponent.html#a1c3bf91efaf6bd073c4649b07f555e20',1,'UIViewComponent::UIViewComponent()'],['../classUIViewComponent.html',1,'UIViewComponent']]],
-  ['unalignedpointercast_9',['unalignedPointerCast',['../group__juce__core-memory.html#ga2bada1e495b85b11decdef546c7c455d',1,'unalignedPointerCast(const void *ptr) noexcept:&#160;juce_Memory.h'],['../group__juce__core-memory.html#ga814a9e2e680da140821d42b2001b3366',1,'unalignedPointerCast(void *ptr) noexcept:&#160;juce_Memory.h']]],
+  ['unalignedpointercast_9',['unalignedPointerCast',['../group__juce__core-memory.html#gaa5927c941870a81adcf7627686432e69',1,'unalignedPointerCast(const void *ptr) noexcept:&#160;juce_Memory.h'],['../group__juce__core-memory.html#ga74cfe82578a32059d75419b3934e3e4f',1,'unalignedPointerCast(void *ptr) noexcept:&#160;juce_Memory.h']]],
   ['unbind_10',['unbind',['../classOpenGLTexture.html#a10272450babb226d7d57563fcc9f867a',1,'OpenGLTexture']]],
   ['uncompressedsize_11',['uncompressedSize',['../structZipFile_1_1ZipEntry.html#aaf153ce5a5d4918a7dabfba87afdff03',1,'ZipFile::ZipEntry']]],
   ['uncompressentry_12',['uncompressEntry',['../classZipFile.html#aa7a3e0db6aa5d2cb75028251501e4dfc',1,'ZipFile::uncompressEntry(int index, const File &amp;targetDirectory, bool shouldOverwriteFiles=true)'],['../classZipFile.html#ab302e6a13fc55a1edcfe35bdb76040a1',1,'ZipFile::uncompressEntry(int index, const File &amp;targetDirectory, OverwriteFiles overwriteFiles, FollowSymlinks followSymlinks)']]],
   ['uncompressto_13',['uncompressTo',['../classZipFile.html#a4d8bc0a4215a9464886909e527946155',1,'ZipFile']]],
   ['undefined_14',['undefined',['../classvar.html#aa8ad714f97623c9c8f0e0e7e139b09d4',1,'var']]],
   ['underlined_15',['underlined',['../classFont.html#a52a35b5dc1e6f782e25283c9283bae4fa3bb23d4d794ac926cd255a886aa37190',1,'Font']]],
-  ['undo_16',['undo',['../classCodeDocument.html#a47208d3029a44c1e9970f41ab5d87c5e',1,'CodeDocument::undo()'],['../namespaceStandardApplicationCommandIDs.html#ab3690a6bc89f72a1872de8994c81cea0a5b866e822eb795f30f0c77ebecc84f7f',1,'StandardApplicationCommandIDs::undo()'],['../classTextEditor.html#a66fea7cc1a783ab14dd5a6386afc53e8',1,'TextEditor::undo()'],['../classUndoManager.html#a39f45c284e8d0df1a0d378e676246931',1,'UndoManager::undo()'],['../classUndoableAction.html#a535a5ca2bdc00edebe2b868ec7c13482',1,'UndoableAction::undo()'],['../classCodeEditorComponent.html#af9a84573dbbe88fe4c1cf0691e4246ba',1,'CodeEditorComponent::undo()']]],
+  ['undo_16',['undo',['../classCodeDocument.html#a47208d3029a44c1e9970f41ab5d87c5e',1,'CodeDocument::undo()'],['../namespaceStandardApplicationCommandIDs.html#ad348cc9beaaea88093769e2da468320aa5b866e822eb795f30f0c77ebecc84f7f',1,'StandardApplicationCommandIDs::undo'],['../classTextEditor.html#a66fea7cc1a783ab14dd5a6386afc53e8',1,'TextEditor::undo()'],['../classUndoManager.html#a39f45c284e8d0df1a0d378e676246931',1,'UndoManager::undo()'],['../classUndoableAction.html#a535a5ca2bdc00edebe2b868ec7c13482',1,'UndoableAction::undo()'],['../classCodeEditorComponent.html#af9a84573dbbe88fe4c1cf0691e4246ba',1,'CodeEditorComponent::undo()']]],
   ['undoableaction_17',['UndoableAction',['../classUndoableAction.html',1,'UndoableAction'],['../classUndoableAction.html#a6a6c5364778d5e863faf4a3def321d55',1,'UndoableAction::UndoableAction()']]],
   ['undocurrenttransactiononly_18',['undoCurrentTransactionOnly',['../classUndoManager.html#ad81c6649e3acc3ab36726c280058d6bb',1,'UndoManager']]],
   ['undomanager_19',['undomanager',['../group__juce__data__structures-undomanager.html',1,'']]],
@@ -57,28 +57,28 @@ var searchData=
   ['unitymousedrag_54',['unityMouseDrag',['../group__juce__audio__plugin__client-Unity.html#ga62e27c29220c0da7c652f3e142a9a060',1,'juce_UnityPluginInterface.h']]],
   ['unitymouseup_55',['unityMouseUp',['../group__juce__audio__plugin__client-Unity.html#gab4f98ceff41381ae8c7ce038bc7a9977',1,'juce_UnityPluginInterface.h']]],
   ['unitysetscreenbounds_56',['unitySetScreenBounds',['../group__juce__audio__plugin__client-Unity.html#ga16199721dbaf4c7d74ce4db0d73b82e6',1,'juce_UnityPluginInterface.h']]],
-  ['unknown_57',['Unknown',['../structExtensionsVisitor_1_1Unknown.html',1,'ExtensionsVisitor::Unknown'],['../structAudioProcessor_1_1CurveData.html#a40813f0ebb00a486ddab9f3a5ebfdcb1a88183b946cc5f0e8c96b2e66e1c74a7e',1,'AudioProcessor::CurveData::Unknown()']]],
-  ['unknown_58',['unknown',['../structRelativeCoordinate_1_1StandardStrings.html#a996870bf66337348b8da0f06c647a65ba2d62eaf1459a818a13429d7acfdfbde2',1,'RelativeCoordinate::StandardStrings::unknown()'],['../classAudioCDBurner.html#a75c01de0b51d56d6f78a1b56ff4da846acfe4c1971599161b618335acaa202fac',1,'AudioCDBurner::unknown()'],['../classAudioChannelSet.html#ab917e490df2e0edfb1087e4c4f8d652eaaa4afa88e8da74c57e088bb364518d6c',1,'AudioChannelSet::unknown()']]],
+  ['unknown_57',['Unknown',['../structExtensionsVisitor_1_1Unknown.html',1,'ExtensionsVisitor::Unknown'],['../structAudioProcessor_1_1CurveData.html#a40813f0ebb00a486ddab9f3a5ebfdcb1a88183b946cc5f0e8c96b2e66e1c74a7e',1,'AudioProcessor::CurveData::Unknown']]],
+  ['unknown_58',['unknown',['../structRelativeCoordinate_1_1StandardStrings.html#a996870bf66337348b8da0f06c647a65ba2d62eaf1459a818a13429d7acfdfbde2',1,'RelativeCoordinate::StandardStrings::unknown'],['../classAudioCDBurner.html#a75c01de0b51d56d6f78a1b56ff4da846acfe4c1971599161b618335acaa202fac',1,'AudioCDBurner::unknown'],['../classAudioChannelSet.html#ab917e490df2e0edfb1087e4c4f8d652eaaa4afa88e8da74c57e088bb364518d6c',1,'AudioChannelSet::unknown']]],
   ['unknownformat_59',['UnknownFormat',['../classImage.html#ab47b5746d2df286ae6f8da6af5463c01a54eec5e1c5371ae7ad7242c6a2be067d',1,'Image']]],
   ['unknownhost_60',['UnknownHost',['../classPluginHostType.html#a69d9330e82ef7520f9aa8b2ad78ce5a8a1c752bc3862092e36ae81d35612e0763',1,'PluginHostType']]],
   ['unknownos_61',['UnknownOS',['../classSystemStats.html#a7697c468b5f6c391096ab483690b68eaa5c49c960dbbdd90f196e55237d268f03',1,'SystemStats']]],
-  ['unloadwhenhidden_62',['unloadWhenHidden',['../structWebBrowserComponent_1_1ConstructWithoutPimpl.html#a3181d4183a66e8a2ef148a31d29689ea',1,'WebBrowserComponent::ConstructWithoutPimpl']]],
-  ['unlockresult_63',['UnlockResult',['../structOnlineUnlockStatus_1_1UnlockResult.html',1,'OnlineUnlockStatus']]],
-  ['unpremultiply_64',['unpremultiply',['../classPixelAlpha.html#a739f660b3d4b93d86bf99e791aea1999',1,'PixelAlpha::unpremultiply()'],['../classPixelRGB.html#a43bd818ac8d55e02b8b3e14cc865a1b7',1,'PixelRGB::unpremultiply()'],['../classPixelARGB.html#a6270aec4f8b98a22f3487be2b8db4dc2',1,'PixelARGB::unpremultiply()']]],
-  ['unquoted_65',['unquoted',['../classString.html#a8d57f9b542acc687afeb480b9e15392c',1,'String']]],
-  ['unsignedtypewithsize_66',['UnsignedTypeWithSize',['../structTypeHelpers_1_1UnsignedTypeWithSize.html',1,'TypeHelpers']]],
-  ['unspecified_67',['unspecified',['../structPushNotifications_1_1Notification.html#a6c4abae95fb5385ac4bf08237dc3a886a51991f458fd433dfe2821ebabb899774',1,'PushNotifications::Notification::unspecified()'],['../group__juce__gui__basics-accessibility.html#ggaf1349587ab6cac7e882cd63e1976682cad415f0e30c471dfdd9bc4f827329ef48',1,'unspecified():&#160;juce_AccessibilityRole.h']]],
-  ['unsubscribefromtopic_68',['unsubscribeFromTopic',['../classPushNotifications.html#ab1894a14c6efdbfb6073125666333986',1,'PushNotifications']]],
-  ['uorder_69',['uorder',['../namespacegl.html#ae22ea52f63236ca60155efbd36731386',1,'gl']]],
-  ['update_70',['update',['../structARAHostModel_1_1PlaybackRegion.html#a78dd9918767dfee7ddcdea830826395b',1,'ARAHostModel::PlaybackRegion::update()'],['../classARAHostModel_1_1AudioSource.html#a6bf740c1925e519410f684f254ccb699',1,'ARAHostModel::AudioSource::update()'],['../classARAHostModel_1_1AudioModification.html#a7341f35153796823ce565939f9146bbe',1,'ARAHostModel::AudioModification::update()'],['../classARAHostModel_1_1MusicalContext.html#aee4459b476ce92b7ea57d2c73e0f86cd',1,'ARAHostModel::MusicalContext::update()'],['../classARAHostModel_1_1RegionSequence.html#aed37296e7266b85da8eeeadc1e5faef1',1,'ARAHostModel::RegionSequence::update()'],['../classAnimatedAppComponent.html#a52d801c9046583cce9cdea2811cad364',1,'AnimatedAppComponent::update()']]],
-  ['updateallitempositions_71',['updateAllItemPositions',['../classToolbar.html#a754c6bad431c7e3a2fa35c6edda41ab5',1,'Toolbar']]],
-  ['updatebounds_72',['updateBounds',['../classComponentPeer.html#a9c0ef89ac8f2a9b8906a7dbe3e4cabe7',1,'ComponentPeer']]],
-  ['updatechildcomponents_73',['updateChildComponents',['../classComponentBuilder.html#ada58c44d9f924f56b43f9552c537f30a',1,'ComponentBuilder']]],
-  ['updatecomponentfromstate_74',['updateComponentFromState',['../classComponentBuilder_1_1TypeHandler.html#a8ca3a127f43eef2849300856a2a0017a',1,'ComponentBuilder::TypeHandler']]],
-  ['updatecontent_75',['updateContent',['../classListBox.html#a3e8cb20434a462c1a102cf62e112e16d',1,'ListBox']]],
-  ['updateembeddedbounds_76',['updateEmbeddedBounds',['../classXEmbedComponent.html#a6421004648d4902f2affc8aa9b1d54cb',1,'XEmbedComponent']]],
-  ['updatehostdisplay_77',['updateHostDisplay',['../classAudioProcessor.html#a6be91089c96844f4fd8fd6d1279af5aa',1,'AudioProcessor']]],
-  ['updatehwndbounds_78',['updateHWNDBounds',['../classHWNDComponent.html#acbf4dc094f0d7e72ce762c617785d475',1,'HWNDComponent']]],
+  ['unlockresult_62',['UnlockResult',['../structOnlineUnlockStatus_1_1UnlockResult.html',1,'OnlineUnlockStatus']]],
+  ['unpremultiply_63',['unpremultiply',['../classPixelAlpha.html#a739f660b3d4b93d86bf99e791aea1999',1,'PixelAlpha::unpremultiply()'],['../classPixelRGB.html#a43bd818ac8d55e02b8b3e14cc865a1b7',1,'PixelRGB::unpremultiply()'],['../classPixelARGB.html#a6270aec4f8b98a22f3487be2b8db4dc2',1,'PixelARGB::unpremultiply()']]],
+  ['unquoted_64',['unquoted',['../classString.html#a8d57f9b542acc687afeb480b9e15392c',1,'String']]],
+  ['unsignedtypewithsize_65',['UnsignedTypeWithSize',['../structTypeHelpers_1_1UnsignedTypeWithSize.html',1,'TypeHelpers']]],
+  ['unspecified_66',['unspecified',['../structPushNotifications_1_1Notification.html#a6c4abae95fb5385ac4bf08237dc3a886a51991f458fd433dfe2821ebabb899774',1,'PushNotifications::Notification::unspecified'],['../group__juce__gui__basics-accessibility.html#ggaf1349587ab6cac7e882cd63e1976682cad415f0e30c471dfdd9bc4f827329ef48',1,'unspecified:&#160;juce_AccessibilityRole.h']]],
+  ['unsubscribefromtopic_67',['unsubscribeFromTopic',['../classPushNotifications.html#ab1894a14c6efdbfb6073125666333986',1,'PushNotifications']]],
+  ['uorder_68',['uorder',['../namespacegl.html#ae22ea52f63236ca60155efbd36731386',1,'gl']]],
+  ['update_69',['update',['../classARAHostModel_1_1MusicalContext.html#aee4459b476ce92b7ea57d2c73e0f86cd',1,'ARAHostModel::MusicalContext::update()'],['../classARAHostModel_1_1AudioModification.html#a7341f35153796823ce565939f9146bbe',1,'ARAHostModel::AudioModification::update()'],['../structARAHostModel_1_1PlaybackRegion.html#a78dd9918767dfee7ddcdea830826395b',1,'ARAHostModel::PlaybackRegion::update()'],['../classARAHostModel_1_1RegionSequence.html#aed37296e7266b85da8eeeadc1e5faef1',1,'ARAHostModel::RegionSequence::update()'],['../classAnimatedAppComponent.html#a52d801c9046583cce9cdea2811cad364',1,'AnimatedAppComponent::update()'],['../classARAHostModel_1_1AudioSource.html#a6bf740c1925e519410f684f254ccb699',1,'ARAHostModel::AudioSource::update()']]],
+  ['updateallitempositions_70',['updateAllItemPositions',['../classToolbar.html#a754c6bad431c7e3a2fa35c6edda41ab5',1,'Toolbar']]],
+  ['updatebounds_71',['updateBounds',['../classComponentPeer.html#a9c0ef89ac8f2a9b8906a7dbe3e4cabe7',1,'ComponentPeer']]],
+  ['updatechildcomponents_72',['updateChildComponents',['../classComponentBuilder.html#ada58c44d9f924f56b43f9552c537f30a',1,'ComponentBuilder']]],
+  ['updatecomponentfromstate_73',['updateComponentFromState',['../classComponentBuilder_1_1TypeHandler.html#a8ca3a127f43eef2849300856a2a0017a',1,'ComponentBuilder::TypeHandler']]],
+  ['updatecontent_74',['updateContent',['../classListBox.html#a3e8cb20434a462c1a102cf62e112e16d',1,'ListBox']]],
+  ['updateembeddedbounds_75',['updateEmbeddedBounds',['../classXEmbedComponent.html#a6421004648d4902f2affc8aa9b1d54cb',1,'XEmbedComponent']]],
+  ['updatehostdisplay_76',['updateHostDisplay',['../classAudioProcessor.html#a6be91089c96844f4fd8fd6d1279af5aa',1,'AudioProcessor']]],
+  ['updatehwndbounds_77',['updateHWNDBounds',['../classHWNDComponent.html#acbf4dc094f0d7e72ce762c617785d475',1,'HWNDComponent']]],
+  ['updatekind_78',['UpdateKind',['../classAudioProcessorGraph.html#ae3b26cb6af3d8811c4a95115c54208ac',1,'AudioProcessorGraph']]],
   ['updatematchedpairs_79',['updateMatchedPairs',['../classMidiMessageSequence.html#a84c73c931fad6357ea81af0323109606',1,'MidiMessageSequence']]],
   ['updatemousecursor_80',['updateMouseCursor',['../classComponent.html#a2d879d2f1eb69e2e828904efc42f0575',1,'Component']]],
   ['updateposition_81',['updatePosition',['../classCallOutBox.html#a19e7a01bb331faba5196e3aa3df07e40',1,'CallOutBox']]],
@@ -109,7 +109,7 @@ var searchData=
   ['usebottomrightcornerresizer_106',['useBottomRightCornerResizer',['../structDialogWindow_1_1LaunchOptions.html#af76a62b12b7dd7e42d6e8374462b5906',1,'DialogWindow::LaunchOptions']]],
   ['usedefaultinputchannels_107',['useDefaultInputChannels',['../structAudioDeviceManager_1_1AudioDeviceSetup.html#af4ee7e75cc152be926202c6a7a822d0c',1,'AudioDeviceManager::AudioDeviceSetup']]],
   ['usedefaultoutputchannels_108',['useDefaultOutputChannels',['../structAudioDeviceManager_1_1AudioDeviceSetup.html#a0506caa1460f630b207e1dcf1093f791',1,'AudioDeviceManager::AudioDeviceSetup']]],
-  ['usedefaultvalue_109',['useDefaultValue',['../classGridItem.html#a3a5e58e592e5efdf1fe64b09ce6b8778a5e5d88077906479ff159508224f49c80',1,'GridItem']]],
+  ['usedefaultvalue_109',['useDefaultValue',['../classGridItem.html#aefa7905cb724d0497929363bbdbee695a5e5d88077906479ff159508224f49c80',1,'GridItem']]],
   ['usefullscreenwhenonedocument_110',['useFullscreenWhenOneDocument',['../classMultiDocumentPanel.html#aae57bc01df58759446d1ad745b1dd0ee',1,'MultiDocumentPanel']]],
   ['usehiddenfile_111',['useHiddenFile',['../classTemporaryFile.html#af04f4ef2ea1bee0b20cdb4c072442e8da5a8f2dba38db83ba22b75362598feaf6',1,'TemporaryFile']]],
   ['usemousewheelmoveifneeded_112',['useMouseWheelMoveIfNeeded',['../classViewport.html#a563d893ae0d00dd9b1c0e293826cdc8e',1,'Viewport']]],
@@ -129,17 +129,18 @@ var searchData=
   ['userparam_126',['userParam',['../namespacegl.html#a938194a8e554f1d1fb5d83a11dea5064',1,'gl']]],
   ['userpicturesdirectory_127',['userPicturesDirectory',['../classFile.html#a3e19cafabb03c5838160263a6e76313daa8e7ec352e54ab4efcae250eba502313',1,'File']]],
   ['userproperties_128',['userProperties',['../structAnalyticsDestination_1_1AnalyticsEvent.html#afcea7cedd0ebe96dfd29c7848429fcb4',1,'AnalyticsDestination::AnalyticsEvent']]],
-  ['usertriedtoclosewindow_129',['userTriedToCloseWindow',['../classComponent.html#a543e70d5a3ff75cc3facb476f4cdb131',1,'Component::userTriedToCloseWindow()'],['../classAlertWindow.html#ac8263176929ac925f0e4aee768094c55',1,'AlertWindow::userTriedToCloseWindow()']]],
-  ['usesanysymbols_130',['usesAnySymbols',['../classExpression.html#a81d8a297c5c153159486a4f1acab2b61',1,'Expression']]],
-  ['usesfileextension_131',['usesFileExtension',['../classPNGImageFormat.html#a8378d3d8b14b42baef523646256d52f5',1,'PNGImageFormat::usesFileExtension()'],['../classGIFImageFormat.html#a34c4b425944129a609bc03869ace660e',1,'GIFImageFormat::usesFileExtension()'],['../classImageFileFormat.html#a9eb5f897a01aa14b136944eee2c7f684',1,'ImageFileFormat::usesFileExtension()'],['../classJPEGImageFormat.html#af1222e40615be2b2b4a0aafa0c0f2e63',1,'JPEGImageFormat::usesFileExtension()']]],
-  ['usesfloatingpointdata_132',['usesFloatingPointData',['../classAudioFormatWriter.html#a876800b982bbe25e583633d3876a9a02',1,'AudioFormatWriter::usesFloatingPointData()'],['../classAudioFormatReader.html#aed5e9ba760d519f110c18053d6adba7a',1,'AudioFormatReader::usesFloatingPointData()']]],
-  ['usesnonzerowinding_133',['usesNonZeroWinding',['../classRelativePointPath.html#a31bd56da083920346e1f0742bd77ae8b',1,'RelativePointPath']]],
-  ['usesseparateinputandoutputblocks_134',['usesSeparateInputAndOutputBlocks',['../structdsp_1_1ProcessContextNonReplacing.html#aa2ebcb6ba943feb1387987953a4349e9',1,'dsp::ProcessContextNonReplacing::usesSeparateInputAndOutputBlocks()'],['../structdsp_1_1ProcessContextReplacing.html#abb54651cb81523520617ada5c4f4a078',1,'dsp::ProcessContextReplacing::usesSeparateInputAndOutputBlocks()']]],
-  ['usetimeslice_135',['useTimeSlice',['../classTimeSliceClient.html#a272b0868c9bd0b5c281cf09dbaa69a9c',1,'TimeSliceClient']]],
-  ['usetreeview_136',['useTreeView',['../classFileBrowserComponent.html#a32888a950cc0e51c8e1350f53bea43d6ab8a34263300c3e493f2a00deee6fc933',1,'FileBrowserComponent']]],
-  ['ustride_137',['ustride',['../namespacegl.html#a9492aafde662bcaaaf7cdd52bbba07dc',1,'gl']]],
-  ['utilities_138',['utilities',['../group__juce__audio__basics-utilities.html',1,'(Global Namespace)'],['../group__juce__audio__processors-utilities.html',1,'(Global Namespace)']]],
-  ['utility_139',['utility',['../group__juce__audio__plugin__client-utility.html',1,'']]],
-  ['utils_140',['utils',['../group__juce__box2d-utils.html',1,'(Global Namespace)'],['../group__juce__opengl-utils.html',1,'(Global Namespace)']]],
-  ['uuid_141',['Uuid',['../classUuid.html',1,'Uuid'],['../classUuid.html#a55663b31db8d26c71fa1b0258ccc34f9',1,'Uuid::Uuid()'],['../classUuid.html#a13364dd33f803cd19c91e04d71dd26ac',1,'Uuid::Uuid(const Uuid &amp;) noexcept'],['../classUuid.html#a1c1c2279f664fb5ecd1c7a40a2427659',1,'Uuid::Uuid(const String &amp;uuidString)'],['../classUuid.html#a9cccd45cc44abc0645c1bd3e73758861',1,'Uuid::Uuid(const uint8 *rawData) noexcept']]]
+  ['userrequestedbypass_129',['userRequestedBypass',['../classAudioProcessorGraph_1_1Node.html#a60387817af71825dc19fef11c86c90e9',1,'AudioProcessorGraph::Node']]],
+  ['usertriedtoclosewindow_130',['userTriedToCloseWindow',['../classComponent.html#a543e70d5a3ff75cc3facb476f4cdb131',1,'Component::userTriedToCloseWindow()'],['../classAlertWindow.html#ac8263176929ac925f0e4aee768094c55',1,'AlertWindow::userTriedToCloseWindow()']]],
+  ['usesanysymbols_131',['usesAnySymbols',['../classExpression.html#a81d8a297c5c153159486a4f1acab2b61',1,'Expression']]],
+  ['usesfileextension_132',['usesFileExtension',['../classImageFileFormat.html#a9eb5f897a01aa14b136944eee2c7f684',1,'ImageFileFormat::usesFileExtension()'],['../classGIFImageFormat.html#a34c4b425944129a609bc03869ace660e',1,'GIFImageFormat::usesFileExtension()'],['../classPNGImageFormat.html#a8378d3d8b14b42baef523646256d52f5',1,'PNGImageFormat::usesFileExtension()'],['../classJPEGImageFormat.html#af1222e40615be2b2b4a0aafa0c0f2e63',1,'JPEGImageFormat::usesFileExtension()']]],
+  ['usesfloatingpointdata_133',['usesFloatingPointData',['../classAudioFormatWriter.html#a876800b982bbe25e583633d3876a9a02',1,'AudioFormatWriter::usesFloatingPointData'],['../classAudioFormatReader.html#aed5e9ba760d519f110c18053d6adba7a',1,'AudioFormatReader::usesFloatingPointData']]],
+  ['usesnonzerowinding_134',['usesNonZeroWinding',['../classRelativePointPath.html#a31bd56da083920346e1f0742bd77ae8b',1,'RelativePointPath']]],
+  ['usesseparateinputandoutputblocks_135',['usesSeparateInputAndOutputBlocks',['../structdsp_1_1ProcessContextNonReplacing.html#aa2ebcb6ba943feb1387987953a4349e9',1,'dsp::ProcessContextNonReplacing::usesSeparateInputAndOutputBlocks()'],['../structdsp_1_1ProcessContextReplacing.html#abb54651cb81523520617ada5c4f4a078',1,'dsp::ProcessContextReplacing::usesSeparateInputAndOutputBlocks()']]],
+  ['usetimeslice_136',['useTimeSlice',['../classTimeSliceClient.html#a272b0868c9bd0b5c281cf09dbaa69a9c',1,'TimeSliceClient']]],
+  ['usetreeview_137',['useTreeView',['../classFileBrowserComponent.html#a32888a950cc0e51c8e1350f53bea43d6ab8a34263300c3e493f2a00deee6fc933',1,'FileBrowserComponent']]],
+  ['ustride_138',['ustride',['../namespacegl.html#a9492aafde662bcaaaf7cdd52bbba07dc',1,'gl']]],
+  ['utilities_139',['utilities',['../group__juce__audio__basics-utilities.html',1,'(Global Namespace)'],['../group__juce__audio__processors-utilities.html',1,'(Global Namespace)']]],
+  ['utility_140',['utility',['../group__juce__audio__plugin__client-utility.html',1,'']]],
+  ['utils_141',['utils',['../group__juce__box2d-utils.html',1,'(Global Namespace)'],['../group__juce__opengl-utils.html',1,'(Global Namespace)']]],
+  ['uuid_142',['Uuid',['../classUuid.html',1,'Uuid'],['../classUuid.html#a55663b31db8d26c71fa1b0258ccc34f9',1,'Uuid::Uuid()'],['../classUuid.html#a13364dd33f803cd19c91e04d71dd26ac',1,'Uuid::Uuid(const Uuid &amp;) noexcept'],['../classUuid.html#a1c1c2279f664fb5ecd1c7a40a2427659',1,'Uuid::Uuid(const String &amp;uuidString)'],['../classUuid.html#a9cccd45cc44abc0645c1bd3e73758861',1,'Uuid::Uuid(const uint8 *rawData) noexcept']]]
 ];
