@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: "_abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvwxz",
-  2: "acdgjstuv",
+  2: "acdgjpstuv",
   3: "cj",
   4: "abcdefghijklmnopqrstuvwxyz~",
   5: "abcdefghijklmnopqrstuvwxyz",
@@ -11,7 +11,7 @@ var indexSectionsWithContent =
   8: "abcdefghijklmnopqrstuvwxyz",
   9: "cgjs",
   10: "deg",
-  11: "abcdefghijklmnoprstuvwxz",
+  11: "abcdefghijklmnopstuvwxz",
   12: "t"
 };
 
