@@ -20,22 +20,22 @@ var searchData=
   ['acidstretch_17',['acidStretch',['../classWavAudioFormat.html#a2e7ca2a8981dd749b7eb8aff8fb3ef8a',1,'WavAudioFormat']]],
   ['acidtempo_18',['acidTempo',['../classWavAudioFormat.html#ac534d5f34f226b43dd6c03387f9aa9a5',1,'WavAudioFormat']]],
   ['action_19',['action',['../structPopupMenu_1_1Item.html#ac33ad5e4444e9215c8b4ab3a76a0243d',1,'PopupMenu::Item']]],
-  ['actions_20',['actions',['../structPushNotifications_1_1Notification.html#a0a9804791528133bf6a31f293300e29e',1,'PushNotifications::Notification::actions()'],['../structPushNotifications_1_1Settings_1_1Category.html#a9d683623a02780751a4ade7f0db55220',1,'PushNotifications::Settings::Category::actions()']]],
+  ['actions_20',['actions',['../structPushNotifications_1_1Notification.html#a0a9804791528133bf6a31f293300e29e',1,'PushNotifications::Notification::actions'],['../structPushNotifications_1_1Settings_1_1Category.html#a9d683623a02780751a4ade7f0db55220',1,'PushNotifications::Settings::Category::actions']]],
   ['active_21',['active',['../classIIRFilterBase.html#ad8b40797aa55fe60ac888e334a20ada1',1,'IIRFilterBase']]],
   ['adddefaultheader_22',['addDefaultHeader',['../structXmlElement_1_1TextFormat.html#a6c3d0ac316e68e5afab517c54b75386f',1,'XmlElement::TextFormat']]],
   ['addr_23',['addr',['../namespacegl.html#aecbebb7ba18a7223d89ea375b7e984d8',1,'gl']]],
-  ['address_24',['address',['../namespacegl.html#a806bc647401f0b1530e579b97b65de84',1,'gl::address()'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address()'],['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address()']]],
+  ['address_24',['address',['../namespacegl.html#a806bc647401f0b1530e579b97b65de84',1,'gl::address'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address'],['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address']]],
   ['advancescale_25',['advanceScale',['../namespacegl.html#a9642fb051ec3be39e183c6ab96b6ab68',1,'gl']]],
   ['alertonlyonce_26',['alertOnlyOnce',['../structPushNotifications_1_1Notification.html#ab134a2585ba8b5064397ed3c56202af0',1,'PushNotifications::Notification']]],
   ['aliceblue_27',['aliceblue',['../namespaceColours.html#a54fefe6d70a212baebc2eda2c854abba',1,'Colours']]],
-  ['aligncontent_28',['alignContent',['../classGrid.html#a315d33b518dd1dc90068a51822b030ac',1,'Grid::alignContent()'],['../classFlexBox.html#a8e1ae8a873d7ff198f439d3088192bcf',1,'FlexBox::alignContent()']]],
-  ['alignitems_29',['alignItems',['../classFlexBox.html#a9e928c10773d54e50e4bfcfc2814f541',1,'FlexBox::alignItems()'],['../classGrid.html#a1ea337d65d875793edcfd4b195040f39',1,'Grid::alignItems()']]],
-  ['alignself_30',['alignSelf',['../classGridItem.html#a8c48a9ecf979e0b9493e12ecc629a916',1,'GridItem::alignSelf()'],['../classFlexItem.html#a7b9190e838f5ee0d70d1cac494621fd7',1,'FlexItem::alignSelf()']]],
+  ['aligncontent_28',['alignContent',['../classGrid.html#a315d33b518dd1dc90068a51822b030ac',1,'Grid::alignContent'],['../classFlexBox.html#a8e1ae8a873d7ff198f439d3088192bcf',1,'FlexBox::alignContent']]],
+  ['alignitems_29',['alignItems',['../classFlexBox.html#a9e928c10773d54e50e4bfcfc2814f541',1,'FlexBox::alignItems'],['../classGrid.html#a1ea337d65d875793edcfd4b195040f39',1,'Grid::alignItems']]],
+  ['alignself_30',['alignSelf',['../classGridItem.html#a8c48a9ecf979e0b9493e12ecc629a916',1,'GridItem::alignSelf'],['../classFlexItem.html#a7b9190e838f5ee0d70d1cac494621fd7',1,'FlexItem::alignSelf']]],
   ['allowalert_31',['allowAlert',['../structPushNotifications_1_1Settings.html#adb0e3b50f514b8179823c55b4c5ee295',1,'PushNotifications::Settings']]],
   ['allowbadge_32',['allowBadge',['../structPushNotifications_1_1Settings.html#a36b3ffa30490b4a45cc7817186f29a14',1,'PushNotifications::Settings']]],
   ['allowedresponses_33',['allowedResponses',['../structPushNotifications_1_1Notification_1_1Action.html#a3d60731f473175aa7dbe1b853227ed8b',1,'PushNotifications::Notification::Action']]],
   ['allowsound_34',['allowSound',['../structPushNotifications_1_1Settings.html#ab9d707cf7dc2476213ac57ecb6a0cd4d',1,'PushNotifications::Settings']]],
-  ['alpha_35',['alpha',['../namespacegl.html#a63bc6ce06ecbc516b6e22d01f9f4dd09',1,'gl::alpha()'],['../structOSCColour.html#a09b39b90c61259a30ca891063bc9bfbc',1,'OSCColour::alpha()'],['../structdsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#aa5dfc4c01cbec7c87be7b263f9c399be',1,'dsp::FilterDesign::IIRPolyphaseAllpassStructure::alpha()']]],
+  ['alpha_35',['alpha',['../namespacegl.html#a63bc6ce06ecbc516b6e22d01f9f4dd09',1,'gl::alpha'],['../structOSCColour.html#a09b39b90c61259a30ca891063bc9bfbc',1,'OSCColour::alpha'],['../structdsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#aa5dfc4c01cbec7c87be7b263f9c399be',1,'dsp::FilterDesign::IIRPolyphaseAllpassStructure::alpha']]],
   ['alphabits_36',['alphaBits',['../classOpenGLPixelFormat.html#a4d947e7a9831d9158f2a0b519d7d3497',1,'OpenGLPixelFormat']]],
   ['anchor_37',['anchor',['../classTextLayout_1_1Glyph.html#a5ed7fd244c70a76748ced04c222cfb87',1,'TextLayout::Glyph']]],
   ['angle_38',['angle',['../namespacegl.html#a1ba013724970a8d5fd396d2a6e859484',1,'gl']]],
@@ -65,11 +65,11 @@ var searchData=
   ['arg3mod_62',['arg3Mod',['../namespacegl.html#a06184929524e3452d6772a1ebcabd0be',1,'gl']]],
   ['arg3rep_63',['arg3Rep',['../namespacegl.html#a6958d133446f362b6579661a608abfa0',1,'gl']]],
   ['argumentdescription_64',['argumentDescription',['../structConsoleApplication_1_1Command.html#a58d4d1dcda368f079ea7f648e89349a2',1,'ConsoleApplication::Command']]],
-  ['arguments_65',['arguments',['../structArgumentList.html#aebbb44f0cabf89cc672536887be82915',1,'ArgumentList::arguments()'],['../structvar_1_1NativeFunctionArgs.html#a6c898b57ab92fb3084a78a4713ae2065',1,'var::NativeFunctionArgs::arguments()']]],
+  ['arguments_65',['arguments',['../structArgumentList.html#aebbb44f0cabf89cc672536887be82915',1,'ArgumentList::arguments'],['../structvar_1_1NativeFunctionArgs.html#a6c898b57ab92fb3084a78a4713ae2065',1,'var::NativeFunctionArgs::arguments']]],
   ['array_66',['array',['../namespacegl.html#a0d93833c93ca0e4d285c4b5610272a52',1,'gl']]],
   ['arrays_67',['arrays',['../namespacegl.html#a045fbf160d30a6b7ea790020431e3e6f',1,'gl']]],
-  ['ascent_68',['ascent',['../classCustomTypeface.html#ab5c74224ec102b6990481b658d189ac4',1,'CustomTypeface::ascent()'],['../classTextLayout_1_1Line.html#ac356b4c8bd159161ac80438457471d7d',1,'TextLayout::Line::ascent()']]],
-  ['associatedcomponent_69',['associatedComponent',['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent()'],['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent()']]],
+  ['ascent_68',['ascent',['../classCustomTypeface.html#ab5c74224ec102b6990481b658d189ac4',1,'CustomTypeface::ascent'],['../classTextLayout_1_1Line.html#ac356b4c8bd159161ac80438457471d7d',1,'TextLayout::Line::ascent']]],
+  ['associatedcomponent_69',['associatedComponent',['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent'],['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent']]],
   ['associatedflexbox_70',['associatedFlexBox',['../classFlexItem.html#ae91dba1ed2ad5a26f0b2733060dbd5ac',1,'FlexItem']]],
   ['aswgaccent_71',['aswgAccent',['../classWavAudioFormat.html#adef504fcd90bd4f2fe8dd162c8b44090',1,'WavAudioFormat']]],
   ['aswgactorgender_72',['aswgActorGender',['../classWavAudioFormat.html#a1dcebe466a57971170eab681cb529f6a',1,'WavAudioFormat']]],
